California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 031 - REFERENDUM CHALLENGING A 2020 LAW PROHIBITING RETAIL SALE OF CERTAIN FLAVORED TOBACCO PRODUCTS. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1436431 | YES ON PROPOSITION 31, COMMITTEE TO PROTECT CALIFORNIA KIDS SPONSORED BY NONPROFIT HEALTH ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1431407 | NO ON PROP 31 - CALIFORNIANS AGAINST PROHIBITION, SPONSORED BY MANUFACTURERS | OPPOSE